pub struct LayoutViewport {
pub geometry: Rect,
pub vbox: Option<ViewBox>,
pub preserve_aspect_ratio: AspectRatio,
pub overflow: Overflow,
}Expand description
Used for elements that need to establish a new viewport, like <svg>.
Fields
geometry: RectPosition and size of the element, per its x/y/width/height properties. For markers, this is markerWidth/markerHeight.
vbox: Option<ViewBox>viewBox attribute
preserve_aspect_ratio: AspectRatiopreserveAspectRatio attribute
overflow: Overflowoverflow property