pub struct StackingContext {
pub element_name: String,
pub transform: Transform,
pub is_visible: bool,
pub opacity: Opacity,
pub filter: Option<Filter>,
pub clip_rect: Option<Rect>,
pub clip_in_object_space: Option<Node<NodeData>>,
pub clip_path: Option<ClipPath>,
pub mask: Option<Node<NodeData>>,
pub mix_blend_mode: MixBlendMode,
pub isolation: Isolation,
pub link_target: Option<String>,
}Expand description
SVG Stacking context, an inner node in the layout tree.
https://www.w3.org/TR/SVG2/render.html#EstablishingStackingContex
This is not strictly speaking an SVG2 stacking context, but a
looser version of it. For example. the SVG spec mentions that a
an element should establish a stacking context if the filter
property applies to the element and is not none. In that case,
the element is rendered as an “isolated group” -
https://www.w3.org/TR/2015/CR-compositing-1-20150113/#csscompositingrules_SVG
Here we store all the parameters that may lead to the decision to actually render an element as an isolated group.
Fields
element_name: Stringtransform: Transformis_visible: boolopacity: Opacityfilter: Option<Filter>clip_rect: Option<Rect>clip_in_object_space: Option<Node<NodeData>>clip_path: Option<ClipPath>mask: Option<Node<NodeData>>mix_blend_mode: MixBlendModeisolation: Isolationlink_target: Option<String>Target from an <a> element
Implementations
Sourceimpl StackingContext
impl StackingContext
pub fn new( draw_ctx: &DrawingCtx, acquired_nodes: &mut AcquiredNodes<'_>, element: &Element, transform: Transform, clip_rect: Option<Rect>, values: &ComputedValues, viewport: &Viewport, ) -> StackingContext
pub fn new_with_link( draw_ctx: &DrawingCtx, acquired_nodes: &mut AcquiredNodes<'_>, element: &Element, transform: Transform, values: &ComputedValues, viewport: &Viewport, link_target: Option<String>, ) -> StackingContext
pub fn should_isolate(&self) -> bool